==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PingSourceSpecBuilder extends PingSourceSpecFluentImpl<PingSourceSpecBuilder> implements VisitableBuilder<PingSourceSpec,PingSourceSpecBuilder> {

    PingSourceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public PingSourceSpecBuilder() { 
        this(true);
    }


    public PingSourceSpecBuilder(Boolean validationEnabled) { 
        this(new PingSourceSpec(), validationEnabled);
    }


    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new PingSourceSpec(), validationEnabled);
    }


    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,PingSourceSpec instance) { 
        this(fluent, instance, true);
    }


    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,PingSourceSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withJsonData(instance.getJsonData()); 
        fluent.withSchedule(instance.getSchedule()); 
        fluent.withSink(instance.getSink()); 
        fluent.withTimezone(instance.getTimezone()); 
        this.validationEnabled = validationEnabled; 
    }


    public PingSourceSpecBuilder(PingSourceSpec instance) { 
        this(instance,true);
    }


    public PingSourceSpecBuilder(PingSourceSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withJsonData(instance.getJsonData()); 
        this.withSchedule(instance.getSchedule()); 
        this.withSink(instance.getSink()); 
        this.withTimezone(instance.getTimezone()); 
        this.validationEnabled = validationEnabled; 
    }


    public PingSourceSpec build() {
        PingSourceSpec buildable = new PingSourceSpec(fluent.getCeOverrides(),fluent.getJsonData(),fluent.getSchedule(),fluent.getSink(),fluent.getTimezone());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PingSourceSpecBuilder that = (PingSourceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/sources/v1beta1/PingSourceSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PingSourceSpecBuilder extends PingSourceSpecFluentImpl<PingSourceSpecBuilder> implements VisitableBuilder<PingSourceSpec,PingSourceSpecBuilder> {

    PingSourceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public PingSourceSpecBuilder() {
        this(true);
    }

    public PingSourceSpecBuilder(Boolean validationEnabled) {
        this(new PingSourceSpec(), validationEnabled);
    }

    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PingSourceSpec(), validationEnabled);
    }

    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,PingSourceSpec instance) {
        this(fluent, instance, true);
    }

    public PingSourceSpecBuilder(PingSourceSpecFluent<?> fluent,PingSourceSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withJsonData(instance.getJsonData()); 
        fluent.withSchedule(instance.getSchedule()); 
        fluent.withSink(instance.getSink()); 
        fluent.withTimezone(instance.getTimezone()); 
        this.validationEnabled = validationEnabled; 
    }

    public PingSourceSpecBuilder(PingSourceSpec instance) {
        this(instance,true);
    }

    public PingSourceSpecBuilder(PingSourceSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withJsonData(instance.getJsonData()); 
        this.withSchedule(instance.getSchedule()); 
        this.withSink(instance.getSink()); 
        this.withTimezone(instance.getTimezone()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditablePingSourceSpec build() {
        EditablePingSourceSpec buildable = new EditablePingSourceSpec(fluent.getCeOverrides(),fluent.getJsonData(),fluent.getSchedule(),fluent.getSink(),fluent.getTimezone());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PingSourceSpecBuilder that = (PingSourceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
